==> gambit-v4_8_9.tgz: gambit-v4_8_9/gsi/_gsilib.c <==
#ifdef ___LINKER_INFO
; File: "_gsilib.c", produced by Gambit v4.8.9
(
408009
(C)
"_gsilib"
(("_gsilib"))
(
"_gsilib"
)
(
)
(
" _gsilib"
)
(
)
(
)
 ()
)
#else
#define ___VERSION 408009
#define ___MODULE_NAME "_gsilib"
#define ___LINKER_ID ____20___gsilib
#define ___MH_PROC ___H__20___gsilib
#define ___SCRIPT_LINE 0
#define ___SYMCOUNT 1
#define ___GLOCOUNT 1
#define ___SUPCOUNT 1
#define ___SUBCOUNT 1
#define ___LBLCOUNT 2
#define ___MODDESCR ___REF_SUB(0)
#include "gambit.h"

___NEED_SYM(___S___gsilib)

___NEED_GLO(___G__20___gsilib)

___BEGIN_SYM
___DEF_SYM(0,___S___gsilib,"_gsilib")
___END_SYM

#define ___SYM___gsilib ___SYM(0,___S___gsilib)

___BEGIN_GLO
___DEF_GLO(0," _gsilib")
___END_GLO

#define ___GLO__20___gsilib ___GLO(0,___G__20___gsilib)
#define ___PRM__20___gsilib ___PRM(0,___G__20___gsilib)

___DEF_SUB_VEC(___X0,5UL)
               ___VEC1(___REF_SYM(0,___S___gsilib))
               ___VEC1(___REF_PRC(1))
               ___VEC1(___REF_FIX(1))
               ___VEC1(___REF_NUL)
               ___VEC1(___REF_FAL)
               ___VEC0

___BEGIN_SUB
 ___DEF_SUB(___X0)
___END_SUB



#undef ___MD_ALL
#define ___MD_ALL ___D_R0 ___D_R1
#undef ___MR_ALL
#define ___MR_ALL ___R_R0 ___R_R1
#undef ___MW_ALL
#define ___MW_ALL ___W_R1
___BEGIN_M_COD
___BEGIN_M_HLBL
___DEF_M_HLBL_INTRO
___DEF_M_HLBL(___L0__20___gsilib)
___END_M_HLBL

___BEGIN_M_SW

#undef ___PH_PROC
#define ___PH_PROC ___H__20___gsilib
#undef ___PH_LBL0
#define ___PH_LBL0 1
#undef ___PD_ALL
#define ___PD_ALL ___D_R0 ___D_R1
#undef ___PR_ALL
#define ___PR_ALL ___R_R0 ___R_R1
#undef ___PW_ALL
#define ___PW_ALL ___W_R1
___BEGIN_P_COD
___BEGIN_P_HLBL
___DEF_P_HLBL_INTRO
___DEF_P_HLBL(___L0__20___gsilib)
___END_P_HLBL
___BEGIN_P_SW
___DEF_SLBL(0,___L0__20___gsilib)
   ___IF_NARGS_EQ(0,___NOTHING)
   ___WRONG_NARGS(0,0,0,0)
___DEF_GLBL(___L__20___gsilib)
   ___SET_R1(___FAL)
   ___JUMPPRM(___NOTHING,___R0)
___END_P_SW
___END_P_COD

___END_M_SW
___END_M_COD

___BEGIN_LBL
 ___DEF_LBL_INTRO(___H__20___gsilib," _gsilib",___REF_FAL,1,0)
,___DEF_LBL_PROC(___H__20___gsilib,0,-1)
___END_LBL

___BEGIN_MOD_PRM
___DEF_MOD_PRM(0,___G__20___gsilib,1)
___END_MOD_PRM

___BEGIN_MOD_C_INIT
___END_MOD_C_INIT

___BEGIN_MOD_GLO
___DEF_MOD_GLO(0,___G__20___gsilib,1)
___END_MOD_GLO

___BEGIN_MOD_SYM_KEY
___DEF_MOD_SYM(0,___S___gsilib,"_gsilib")
___END_MOD_SYM_KEY

#endif

==> gambit-v4_9_0.tgz: gambit-v4_9_0/gsi/_gsilib.c <==
#ifdef ___LINKER_INFO
; File: "_gsilib.c", produced by Gambit v4.9.0
(
409000
(C)
"_gsilib"
(("_gsilib"))
(
"_gsilib"
)
(
)
(
"_gsilib#"
)
(
)
(
)
 ()
)
#else
#define ___VERSION 409000
#define ___MODULE_NAME "_gsilib"
#define ___LINKER_ID ___LNK___gsilib
#define ___MH_PROC ___H___gsilib
#define ___SCRIPT_LINE 0
#define ___SYMCOUNT 1
#define ___GLOCOUNT 1
#define ___SUPCOUNT 1
#define ___SUBCOUNT 1
#define ___LBLCOUNT 2
#define ___MODDESCR ___REF_SUB(0)
#include "gambit.h"

___NEED_SYM(___S___gsilib)

___NEED_GLO(___G___gsilib_23_)

___BEGIN_SYM
___DEF_SYM(0,___S___gsilib,"_gsilib")
___END_SYM

#define ___SYM___gsilib ___SYM(0,___S___gsilib)

___BEGIN_GLO
___DEF_GLO(0,"_gsilib#")
___END_GLO

#define ___GLO___gsilib_23_ ___GLO(0,___G___gsilib_23_)
#define ___PRM___gsilib_23_ ___PRM(0,___G___gsilib_23_)

___DEF_SUB_VEC(___X0,5UL)
               ___VEC1(___REF_SYM(0,___S___gsilib))
               ___VEC1(___REF_PRC(1))
               ___VEC1(___REF_FIX(1))
               ___VEC1(___REF_NUL)
               ___VEC1(___REF_FAL)
               ___VEC0

___BEGIN_SUB
 ___DEF_SUB(___X0)
___END_SUB



#undef ___MD_ALL
#define ___MD_ALL ___D_R0 ___D_R1
#undef ___MR_ALL
#define ___MR_ALL ___R_R0 ___R_R1
#undef ___MW_ALL
#define ___MW_ALL ___W_R1
___BEGIN_M_COD
___BEGIN_M_HLBL
___DEF_M_HLBL_INTRO
___DEF_M_HLBL(___L0___gsilib_23_)
___END_M_HLBL

___BEGIN_M_SW

#undef ___PH_PROC
#define ___PH_PROC ___H___gsilib_23_
#undef ___PH_LBL0
#define ___PH_LBL0 1
#undef ___PD_ALL
#define ___PD_ALL ___D_R0 ___D_R1
#undef ___PR_ALL
#define ___PR_ALL ___R_R0 ___R_R1
#undef ___PW_ALL
#define ___PW_ALL ___W_R1
___BEGIN_P_COD
___BEGIN_P_HLBL
___DEF_P_HLBL_INTRO
___DEF_P_HLBL(___L0___gsilib_23_)
___END_P_HLBL
___BEGIN_P_SW
___DEF_SLBL(0,___L0___gsilib_23_)
   ___IF_NARGS_EQ(0,___NOTHING)
   ___WRONG_NARGS(0,0,0,0)
___DEF_GLBL(___L___gsilib_23_)
   ___SET_R1(___FAL)
   ___JUMPPRM(___NOTHING,___R0)
___END_P_SW
___END_P_COD

___END_M_SW
___END_M_COD

___BEGIN_LBL
 ___DEF_LBL_INTRO(___H___gsilib_23_,"_gsilib#",___REF_FAL,1,0)
,___DEF_LBL_PROC(___H___gsilib_23_,0,-1)
___END_LBL

___BEGIN_MOD_PRM
___DEF_MOD_PRM(0,___G___gsilib_23_,1)
___END_MOD_PRM

___BEGIN_MOD_C_INIT
___END_MOD_C_INIT

___BEGIN_MOD_GLO
___DEF_MOD_GLO(0,___G___gsilib_23_,1)
___END_MOD_GLO

___BEGIN_MOD_SYM_KEY
___DEF_MOD_SYM(0,___S___gsilib,"_gsilib")
___END_MOD_SYM_KEY

#endif
